@@ -1,6 +1,9 @@
-from rest_framework.permissions import DjangoObjectPermissions
+from rest_framework import permissions
 
-class CheckSafeMethodsDjangoModelPermissions(permissions.DjangoObjectPermissions):
+
+class CheckSafeMethodsDjangoModelPermissions(
+    permissions.DjangoObjectPermissions
+):
     """
     Similar to `DjangoObjectPermissions`, but adding 'view' permissions.
     """
@@ -17,4 +20,3 @@ class CheckSafeMethodsDjangoModelPermissions(permissions.DjangoObjectPermissions
 
     def has_object_permission(self, request, view, obj):
         return True
-
